/*
 * @(#)ParentLevelAccessor.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy;

import chrriis.uihierarchy.compatibility.ArrayList;
import chrriis.uihierarchy.compatibility.List;

/**
 * An accessor for a single level accessor that is manipulating a parent level.
 * @version 1.0 2003.12.26
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class ParentLevelAccessor extends SingleLevelAccessor {

  /**
   * Construct an HLevelAccessor.
   * @param uihConfig The configuration that this accessor is going to use.
   * @param hLevel The hierarchy level that is manipulated by this accessor.
   */
  protected ParentLevelAccessor(UIHConfig uihConfig, HParentLevel hParentLevel) {
    super(uihConfig, hParentLevel);
  }

  /**
   * Get the parent level manipulated by this accessor.
   * @return The parent level.
   */
  protected HParentLevel getHParentLevel() {
    return (HParentLevel)getHLevel();
  }

  /**
   * Add a hierarchy as a child of the level contained in this accessor.
   * If the parent is realized and the child level is not, then it gets
   * realized.
   * @param uih The hierarchy to add.
   */
  public void add(UIH uih) {
    add(-1, uih);
  }

  /**
   * Add a hierarchy as a child of the level contained in this accessor.
   * If the parent is realized and the child level is not, then it gets
   * realized.
   * @param index The index at which to add the levels from the hierarchy.
   * @param uih The hierarchy to add.
   */
  public void add(int index, UIH uih) {
    if(!uih.isClosed()) {
      throw new IllegalStateException("Cannot add a hierarchy that is not closed!");
    }
    HParentLevel hLevel = getHParentLevel();
    List topLevelsList = uih.getTopLevelsList();
    for(int i=0; i<topLevelsList.size(); i++) {
      hLevel.addChild(index==-1? -1: index++, (HLevel)topLevelsList.get(i));
    }
  }

//  /**
//   * Remove the child level of the parent level that is manipulated.
//   * @param index The index of the child to remove.
//   */
//  public void remove(int index) {
//    getHLevels()[index].remove();
//  }

  /**
   * Remove all the children levels of the parent level that is manipulated.
   */
  public void removeAll() {
    List copyList = new ArrayList(getHParentLevel().getChildrenList());
    for(int i=0; i<copyList.size(); i++) {
      ((HLevel)copyList.get(i)).remove();
    }
  }

//  /**
//   * Get the children count. This only works if the level is a parent level (or
//   * else generates an exception).
//   * @return The children count.
//   */
//  public int getChildrenCount() {
//    return getHLevel().getChildrenList().size();
//  }

}
