/*
 * @(#)Collection.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.compatibility;

/**
 * The Collection compatible version.
 * @version 1.0 2004.01.11
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public interface Collection {

  /**
   * Returns true if this collection contains the specified element.
   * @param o The object to look for.
   * @return True if found.
   */
  public boolean contains(Object o);

  /**
   * Removes the first occurrence in this list of the specified element (optional operation). 
   * @param o The element to remove.
   * @return True if the element was present.
   */
  public boolean remove(Object o);

  /**
   * Removes all this collection's elements that are also contained in the specified collection (optional operation).
   * @param c The collection of elements to remove.
   * @return True if the collection was affected by this operation.
   */
  public boolean removeAll(Collection c);
 
  /**
   * Returns true if this list contains no elements.
   * @return True if this list is empty.
   */
  public boolean isEmpty();

  /**
   * Returns the number of elements in this list.
   * @return The size.
   */
  public int size();

  /**
   * Returns an array containing all of the elements in this collection. 
   * @return The array.
   */
  public Object[] toArray();

  /**
   * Returns an array containing all of the elements in this collection; the runtime type of the returned array is that of the specified array.
   * @param a The array from which to get the type.
   * @return The array.
   */
  public Object[] toArray(Object[] a);

  /**
   * Adds the specified element to this set if it is not already present (optional operation).
   * @param o The object to add.
   * @return True if changed.
   */
  public boolean add(Object o);

  /**
   * Adds all of the elements in the specified collection to this set if they're not already present (optional operation).
   * @param c The collection.
   * @return True if changed.
   */
  public boolean addAll(Collection c);

}
