/*
 * @(#)Compatibility.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.compatibility;

/**
 * A class that centralizes compatibility information.
 * @version 1.0 2004.01.11
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class Compatibility {

  /** Indicate if Swing is present. */
  protected static boolean isSwingPresent;

  /** The null object. */
  protected static final Object NULL = new Object();

  /** The Java version unknown constant. */
  public static final int JAVA_UNKNOWN = 0;
  /** The Java version 1.1 constant. */
  public static final int JAVA_1_1 = 1;
  /** The Java version 1.2 constant. */
  public static final int JAVA_1_2 = 2;
  /** The Java version 1.3 constant. */
  public static final int JAVA_1_3 = 3;
  /** The Java version 1.4 constant. */
  public static final int JAVA_1_4 = 4;
  /** The Java version 1.5 constant. */
  public static final int JAVA_1_5 = 5;

  /** The version of Java. */
  protected static int javaVersion;

  static {
    // Detection of the Java version.
    int _javaVersion = JAVA_UNKNOWN;
    try {
      Class.forName("java.util.Vector");
      _javaVersion = JAVA_1_1;
      Class.forName("java.lang.ThreadLocal");
      _javaVersion = JAVA_1_2;
      Class.forName("java.lang.StrictMath");
      _javaVersion = JAVA_1_3;
      Class.forName("java.lang.StackTraceElement");
      _javaVersion = JAVA_1_4;
      Class.forName("java.awt.MouseInfo");
      _javaVersion = JAVA_1_5;
    } catch(Exception e){}
    javaVersion = _javaVersion;
    if(javaVersion == JAVA_1_1) {
      try {
        SwingUtilities_1_1.eventDispatchThreadClass.getName();
      } catch(Error e) {
        throw new IllegalStateException("UIHierarchy JDK 1.1 extension must be present in the class path!");
      }
    }
    // Detection of Swing's presence on JDK 1.1.
    boolean _isSwingPresent = false;
    if(javaVersion == JAVA_1_1) {
      try {
        Class.forName("javax.swing.JComponent");
        _isSwingPresent = true;
      } catch(Exception e){}
    } else {
      _isSwingPresent = true;
    }
    isSwingPresent = _isSwingPresent;
  }

  /**
   * Indicate whether the Java version is 1.1.
   * @return True if the Java version is 1.1.
   */
  public static boolean isJava1_1() {
    return getJavaVersion() == JAVA_1_1;
  }

  /**
   * Get the version of JAVA.
   * @return The version.
   */
  public static int getJavaVersion() {
    return javaVersion;
  }

  /**
   * Indicate if Swing is present.
   * @return True if Swing is present.
   */
  public static boolean isSwingPresent() {
    return isSwingPresent;
  }

}
