/*
 * @(#)Component.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.compatibility;

import java.lang.reflect.Method;

/**
 * A class that centralizes the components related settings.
 * @version 1.0 2004.01.11
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class Component {

  /**
   * Construct a component.
   */
  protected Component() {}

  /** The getPeer method */
  protected static Method getPeerMethod;

  /**
   * Indicate whether the specified component is displayable.
   * @param component The component for which to get the property.
   * @return True if the component is displayable.
   */
  public static boolean isDisplayable(java.awt.Component component) {
    if(Compatibility.isJava1_1()) {
      // getPeer is deprecated so reflection is used to remove warnings
      if(getPeerMethod == null) {
        try {
          getPeerMethod = java.awt.Component.class.getMethod("getPeer", null);
        } catch(Exception e){}
      }
      try {
        return getPeerMethod.invoke(component, null) != null;
      } catch(Exception e) {
        throw new IllegalStateException(e.getMessage());
      }
    }
    return component.isDisplayable();
  }

}
