/*
 * @(#)HashMap.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.compatibility;

/**
 * The HashMap compatible version.
 * @version 1.0 2003.
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class HashMap implements Map {

  /** The hash map. */
  protected Object hashMap;

  /**
   * Constructs an empty HashMap with the default initial capacity (16) and the default load factor (0.75).
   */
  public HashMap() {
    if(Compatibility.isJava1_1()) {
      hashMap = new HashMap_1_1();
    } else {
      hashMap = new java.util.HashMap();
    }
  }

  /**
   * Constructs an empty HashMap with the specified initial capacity and the default load factor (0.75).
   * @param initialCapacity The initial capacity.
   */
  public HashMap(int initialCapacity) {
    if(Compatibility.isJava1_1()) {
      hashMap = new HashMap_1_1(initialCapacity);
    } else {
      hashMap = new java.util.HashMap(initialCapacity);
    }
  }

  /**
   * Returns true if this map contains a mapping for the specified key. 
   * @param key The key.
   * @return True if found.
   */
  public boolean containsKey(Object key) {
    if(Compatibility.isJava1_1()) {
      return ((HashMap_1_1)hashMap).containsKey(key);
    }
    return ((java.util.HashMap)hashMap).containsKey(key);
  }

  /**
   * Returns the value to which this map maps the specified key.
   * @param key The key.
   * @return The object.
   */
  public Object get(Object key) {
    if(Compatibility.isJava1_1()) {
      return ((HashMap_1_1)hashMap).get(key);
    }
    return ((java.util.HashMap)hashMap).get(key);
  }

  /**
   * Associates the specified value with the specified key in this map (optional operation).
   * @param key The key.
   * @param value The value.
   * @return The previous value.
   */
  public Object put(Object key, Object value) {
    if(Compatibility.isJava1_1()) {
      return ((HashMap_1_1)hashMap).put(key, value);
    }
    return ((java.util.HashMap)hashMap).put(key, value);
  }

  /**
   * Returns a set view of the keys contained in this map.
   * @return The set.
   */
  public Set keySet() {
    if(Compatibility.isJava1_1()) {
      return ((HashMap_1_1)hashMap).keySet();
    }
    Object[] objects = ((java.util.HashMap)hashMap).keySet().toArray();
    HashSet hashSet = new HashSet(objects.length);
    for(int i=0; i<objects.length; i++) {
      hashSet.add(objects[i]);
    }
    return hashSet;
  }

}
