/*
 * @(#)BoxHConstraints.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.constraints;

import java.awt.Container;
import chrriis.uihierarchy.compatibility.HashMap;
import chrriis.uihierarchy.compatibility.Map;
import java.util.StringTokenizer;

import javax.swing.JComponent;

import chrriis.uihierarchy.SingleLevelAccessor;

/**
 * The constraints for a Box layout. Constraints are manipulated by the
 * <code>createConstraints</code> method, if they are a String.
 * <br><br>
 * The format is of the form "key1=value1, key2=value2, ..." where pairs are:
 * <br>
 * <ul>
 * <li>x = a float.
 * <li>y = a float.
 * </ul>
 * @version 1.1 2003.11.03
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class BoxHConstraints implements LayoutHConstraints {

  /**
   * Create the constraints for a Box layout, if the parameter is a String.
   * @param accessor The accessor of the level for which to create the
   * constraints.
   * @param parentContainer The parent container.
   * @param constraints The constraints of the component.
   * @return null, or the original constraints if not a String.
   */
  public Object createConstraints(SingleLevelAccessor accessor, Container parentContainer, Object constraints) {
    if(!(constraints instanceof String)) {
      return constraints;
    }
    Map constraintsMap = new HashMap(2);
    StringTokenizer st = new StringTokenizer((String)constraints, ",");
    while(st.hasMoreTokens()) {
      String token = st.nextToken();
      int index = token.indexOf("=");
      if(index != -1) {
        String key = token.substring(0, index).trim().toLowerCase();
        String value = token.substring(index + 1).trim();
        if(key.equals("x") || key.equals("y")) {
          constraintsMap.put(key, new Float(value));
        }
      }
    }
    Float value = (Float)constraintsMap.get("x");
    JComponent component = (JComponent)accessor.getComponent();
    if(value != null) {
      component.setAlignmentX(value.floatValue());
    }
    value = (Float)constraintsMap.get("y");
    if(value != null) {
      component.setAlignmentY(value.floatValue());
    }
    return null;
  }

}
