/*
 * @(#)BorderHConstraints.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.constraints;

import java.awt.Container;

import chrriis.uihierarchy.SingleLevelAccessor;

/**
 * The constraints for a Flow layout, which are only meant to raise an
 * exception as a flow layout does not accept constraints.
 * <br>
 * This is meant to catch the common mistake of a developer specifing some
 * constraints but omitting to set the layout of the parent component, which by
 * default is usually a Flow layout that does not complain about the given
 * constraints.
 * @version 1.1 2003.02.24
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class FlowHConstraints implements LayoutHConstraints {

  /**
   * Create the constraints for a flow layout.
   * @param accessor The accessor of the level for which to create the
   * constraints.
   * @param parentContainer The parent container.
   * @param constraints The constraints of the component.
   * @return null if the constraints are null, or raises an exception as it does
   * not allow the use of constraints.
   */
  public Object createConstraints(SingleLevelAccessor accessor, Container parentContainer, Object constraints) {
    if(constraints == null) {
      return constraints;
    }
    throw new IllegalStateException("FlowLayout does not accept constraints!");
  }

}
