/*
 * @(#)StringComponentCreator.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.creator;

import java.awt.Component;
import java.awt.Container;
import java.awt.Label;

import javax.swing.JComponent;
import javax.swing.JLabel;

import chrriis.uihierarchy.UIHConfig;
import chrriis.uihierarchy.compatibility.Compatibility;

/**
 * A component creator that handles Strings.
 * @version 1.0 2003.10.24
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class StringComponentCreator implements ComponentCreator {

  /**
   * Create a component from a String. The resulting component is a label.
   * @param uihConfig The configuration in use.
   * @param parentContainer The container that will be the parent of the
   * component to create. The addition of the component to the parent will be
   * automatic so this method should not affect this behaviour. The parent can
   * be null when the node is a sub node.
   * @param component The component's representation from which to create the
   * component.
   * @param level The indication of the level of the component. It is either
   * <code>NODE</code> or <code>LEAF</code>. Root nodes are differentiated from
   * nodes by the fact that the parent container is null.
   * @return A label with the specified text.
   * @see chrriis.uihierarchy.creator.ComponentCreator#createComponent(chrriis.uihierarchy.UIHConfig, java.awt.Container, java.lang.Object, int)
   */
  public Component createComponent(UIHConfig uihConfig, Container parentContainer, Object component, int level) {
    if(Compatibility.isSwingPresent() && (parentContainer instanceof JComponent || (parentContainer == null && uihConfig.isSwingPreferred()))) {
      return new JLabel((String)component);
    }
    return new Label((String)component);
  }

}
