/*
 * @(#)ScreenUnit.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.unit;

import java.awt.Toolkit;

/**
 * A unit to use as a superclass for resolution based units.
 * @version 1.0 2005.02.01
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
abstract class ScreenUnit extends Unit {

  /** The ratio. */
  protected double screenUnitRatio;

  /**
   * Construct a new ScreenUnit.
   */
  protected ScreenUnit() {
    screenUnitRatio = Toolkit.getDefaultToolkit().getScreenResolution();
  }

  /**
   * Get the ratio to use when making conversions. The ratio is so that:<br>
   * <code>unitValue * ratio == pixelValue</code>.
   * @return The ratio to use for conversions.
   */
  protected double getRatio() {
    return screenUnitRatio;
  }

  /**
   * Get the double value resulting from the conversion of the value from the specified unit.
   * @param unit The unit from which to convert.
   * @param value The value to convert.
   * @return The result of the conversion.
   */
  public double doubleValue(Unit unit, double value) {
    return convert(unit, value);
  }

}
